from django.conf.urls import patterns, url
from django.views.decorators.csrf import csrf_exempt

from . import views
from django_openid_auth import views as auth_view


urlpatterns = patterns(
    '',
    url(r'^api-auth/openid/login/$', csrf_exempt(auth_view.login_begin), name='openid-login'),
    url(r'^api-auth/openid/complete/$', auth_view.login_complete, name='openid-complete'),
    url(r'^api-auth/openid/logo.gif$', auth_view.logo, name='openid-logo'),
    url(r'^api-auth/login_complete/', views.login_complete),
)



from __future__ import unicode_literals

import six
from django.conf import settings
from django.contrib.auth.decorators import login_required
from django.http import HttpResponseRedirect

from nodeconductor.core.views import RefreshTokenMixin


@login_required
def login_complete(request):
    """
    Callback view called after user has successfully logged in.
    Redirects user agent to frontend view with valid token as hash parameter.
    """
    token = RefreshTokenMixin().refresh_token(request.user)
    url_template = settings.NODECONDUCTOR_AUTH_OPENID['LOGIN_URL_TEMPLATE']
    url = url_template.format(token=token.key)
    return HttpResponseRedirect(url)


def login_failed(request, message):
    url_template = settings.NODECONDUCTOR_AUTH_OPENID['LOGIN_FAILED_URL_TEMPLATE']
    params = six.moves.urllib.parse.urlencode(dict(message=message))
    url = '%s?%s' % (url_template, params)
    return HttpResponseRedirect(url)



from nodeconductor.core.permissions import FilteredCollaboratorsPermissionLogic


PERMISSION_LOGICS = (
    ('django_openid_auth.UserOpenID', FilteredCollaboratorsPermissionLogic(user_field='user', any_permission=True)),
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.conf import settings
from django.contrib.auth import get_user_model
from django.db import migrations


def update_usernames(apps, schema_editor):
    User = get_user_model()
    registration_method = settings.NODECONDUCTOR_AUTH_OPENID.get('NAME', 'openid')
    for user in User.objects.filter(registration_method=registration_method).iterator():
        user.username = user.username.replace(' ', '')
        user.save()


class Migration(migrations.Migration):

    operations = [
            migrations.RunPython(update_usernames),
    ]
